@@ -28,12 +28,7 @@
 #include <cstdlib> // for atoi
 #include <limits.h> // for SHRT_MIN
 #include <cassert>
-
-#if (__GNUC__ < 3)
-#include <strstream>
-#else
 #include <sstream>
-#endif
 
 //dmm This will make everything excruciatingly slow if defined:
 //#define DEBUG_PITCH
@@ -481,19 +476,10 @@ Key::Key(int accidentalCount, bool isSharp, bool isMinor) :
         }
     }
 
-#if (__GNUC__ < 3)
-    std::ostrstream os;
-#else
     std::ostringstream os;
-#endif
-
     os << "No " << (isMinor ? "minor" : "major") << " key with "
        << accidentalCount << (isSharp ? " sharp(s)" : " flat(s)");
 
-#if (__GNUC__ < 3)
-    os << std::ends;
-#endif
-
     throw BadKeySpec(os.str());
 }
 
@@ -514,19 +500,11 @@ Key::Key(int tonicPitch, bool isMinor) :
         }
     }
 
-#if (__GNUC__ < 3)
-    std::ostrstream os;
-#else
     std::ostringstream os;
-#endif
 
     os << "No " << (isMinor ? "minor" : "major") << " key with tonic pitch "
        << tonicPitch;
 
-#if (__GNUC__ < 3)
-    os << std::ends;
-#endif
-
     throw BadKeySpec(os.str());
 }
     
