@@ -44,9 +44,9 @@
 #include "gui/widgets/QuantizeParameters.h"
 #include "TabbedConfigurationPage.h"
 #include <kcombobox.h>
-#include <kconfig.h>
-#include <kfontrequester.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdefontrequester.h>
+#include <tdemessagebox.h>
 #include <tqcheckbox.h>
 #include <tqcombobox.h>
 #include <tqfont.h>
@@ -66,7 +66,7 @@
 namespace Rosegarden
 {
 
-NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
+NotationConfigurationPage::NotationConfigurationPage(TDEConfig *cfg,
         TQWidget *parent,
         const char *name) :
         TabbedConfigurationPage(cfg, parent, name)
@@ -539,7 +539,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
     layout->addWidget
         (new TQLabel(i18n("Text font"), frame), row, 0);
-    m_textFont = new KFontRequester(frame);
+    m_textFont = new TDEFontRequester(frame);
     TQFont textFont = m_cfg->readFontEntry("textfont", &defaultTextFont);
     m_textFont->setFont(textFont);
     layout->addMultiCellWidget(m_textFont, row, row, 1, 3);
@@ -547,7 +547,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
     layout->addWidget
         (new TQLabel(i18n("Sans-serif font"), frame), row, 0);
-    m_sansFont = new KFontRequester(frame);
+    m_sansFont = new TDEFontRequester(frame);
     TQFont sansFont = m_cfg->readFontEntry("sansfont", &defaultSansFont);
     m_sansFont->setFont(sansFont);
     layout->addMultiCellWidget(m_sansFont, row, row, 1, 3);
@@ -559,7 +559,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
     layout->addWidget
         (new TQLabel(i18n("Time Signature font"), frame), row, 0);
-    m_timeSigFont = new KFontRequester(frame);
+    m_timeSigFont = new TDEFontRequester(frame);
     TQFont timeSigFont = m_cfg->readFontEntry("timesigfont", &defaultTimeSigFont);
     m_timeSigFont->setFont(timeSigFont);
     layout->addMultiCellWidget(m_timeSigFont, row, row, 1, 3);
