@@ -59,14 +59,14 @@
 #include "gui/general/MidiPitchLabel.h"
 #include "gui/kdeext/KTmpStatusMsg.h"
 #include "gui/dialogs/EventFilterDialog.h"
-#include <kaction.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeaction.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <kstatusbar.h>
 #include <kstddirs.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <klineeditdlg.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kxmlguiclient.h>
 #include <tqbuttongroup.h>
 #include <tqcanvas.h>
@@ -146,7 +146,7 @@ EventView::EventView(RosegardenGUIDoc *doc,
     connect(m_filterGroup, TQT_SIGNAL(released(int)),
             TQT_SLOT(slotModifyFilter(int)));
 
-    m_eventList = new KListView(getCentralWidget());
+    m_eventList = new TDEListView(getCentralWidget());
     m_eventList->setItemsRenameable(true);
 
     m_grid->addWidget(m_eventList, 2, 1);
@@ -1117,56 +1117,56 @@ EventView::setupActions()
 {
     EditViewBase::setupActions("eventlist.rc");
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/event-insert.png"));
 
-    new KAction(i18n("&Insert Event"), icon, Key_I, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Insert Event"), icon, Key_I, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditInsert()), actionCollection(),
                 "insert");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/event-delete.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(i18n("&Delete Event"), icon, Key_Delete, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Delete Event"), icon, Key_Delete, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditDelete()), actionCollection(),
                 "delete");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(i18n("&Edit Event"), icon, Key_E, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Edit Event"), icon, Key_E, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditEvent()), actionCollection(),
                 "edit_simple");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit-advanced.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(i18n("&Advanced Event Editor"), icon, Key_A, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Advanced Event Editor"), icon, Key_A, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditEventAdvanced()), actionCollection(),
                 "edit_advanced");
 
     //    icon = TQIconSet(TQCanvasPixmap(pixmapDir + "/toolbar/eventfilter.xpm"));
-    new KAction(i18n("&Filter Selection"), "filter", Key_F, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Filter Selection"), "filter", Key_F, TQT_TQOBJECT(this),
                 TQT_SLOT(slotFilterSelection()), actionCollection(),
                 "filter_selection");
 
-    new KAction(i18n("Select &All"), Key_A + CTRL, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Select &All"), Key_A + CTRL, TQT_TQOBJECT(this),
                 TQT_SLOT(slotSelectAll()), actionCollection(),
                 "select_all");
 
-    new KAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
                 TQT_SLOT(slotClearSelection()), actionCollection(),
                 "clear_selection");
 
     m_config->setGroup(EventViewConfigGroup);
     int timeMode = m_config->readNumEntry("timemode", 0);
 
-    KRadioAction *action;
+    TDERadioAction *action;
 
     pixmap.load(pixmapDir + "/toolbar/time-musical.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotMusicalTime()),
                               actionCollection(), "time_musical");
     action->setExclusiveGroup("timeMode");
@@ -1176,7 +1176,7 @@ EventView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-real.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotRealTime()),
                               actionCollection(), "time_real");
     action->setExclusiveGroup("timeMode");
@@ -1186,7 +1186,7 @@ EventView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-raw.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotRawTime()),
                               actionCollection(), "time_raw");
     action->setExclusiveGroup("timeMode");
@@ -1194,7 +1194,7 @@ EventView::setupActions()
         action->setChecked(true);
 
     if (m_isTriggerSegment) {
-        KAction *action = actionCollection()->action("open_in_matrix");
+        TDEAction *action = actionCollection()->action("open_in_matrix");
         if (action)
             delete action;
         action = actionCollection()->action("open_in_notation");
