@@ -25,7 +25,7 @@
 
 #include "AudioMixerWindow.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "AudioPlugin.h"
 #include "AudioPluginManager.h"
@@ -54,11 +54,11 @@
 #include "sound/MappedCommon.h"
 #include "sound/MappedEvent.h"
 #include "sound/MappedStudio.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
-#include <kaction.h>
-#include <kglobal.h>
-#include <kmainwindow.h>
+#include <tdeaction.h>
+#include <tdeglobal.h>
+#include <tdemainwindow.h>
 #include <kstdaction.h>
 #include <tqaccel.h>
 #include <tqcolor.h>
@@ -102,86 +102,86 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
 
     TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                              ("transport-play")));
-    KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
+    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
                 TQT_SIGNAL(play()), actionCollection(), "play");
     // Alternative shortcut for Play
-    KShortcut playShortcut = play->shortcut();
+    TDEShortcut playShortcut = play->shortcut();
     playShortcut.append( KKey(Key_Return + CTRL) );
     play->setShortcut(playShortcut);
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-stop")));
-    new KAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
                 TQT_SIGNAL(stop()), actionCollection(), "stop");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind")));
-    new KAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
                 TQT_SIGNAL(rewindPlayback()), actionCollection(),
                 "playback_pointer_back_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd")));
-    new KAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
                 TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
                 "playback_pointer_forward_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind-end")));
-    new KAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
                 "playback_pointer_start");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd-end")));
-    new KAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
                 "playback_pointer_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-record")));
-    new KAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(record()), actionCollection(),
                 "record");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-panic")));
-    new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
                 TQT_SIGNAL(panic()), actionCollection(),
                 "panic");
 
     unsigned int mixerOptions = m_studio->getMixerDisplayOptions();
 
-    (new KToggleAction(i18n("Show Audio &Faders"), 0, TQT_TQOBJECT(this),
+    (new TDEToggleAction(i18n("Show Audio &Faders"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotToggleFaders()), actionCollection(),
                        "show_audio_faders"))->setChecked
     (!(mixerOptions & MIXER_OMIT_FADERS));
 
-    (new KToggleAction(i18n("Show Synth &Faders"), 0, TQT_TQOBJECT(this),
+    (new TDEToggleAction(i18n("Show Synth &Faders"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotToggleSynthFaders()), actionCollection(),
                        "show_synth_faders"))->setChecked
     (!(mixerOptions & MIXER_OMIT_SYNTH_FADERS));
 
-    (new KToggleAction(i18n("Show &Submasters"), 0, TQT_TQOBJECT(this),
+    (new TDEToggleAction(i18n("Show &Submasters"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotToggleSubmasters()), actionCollection(),
                        "show_audio_submasters"))->setChecked
     (!(mixerOptions & MIXER_OMIT_SUBMASTERS));
 
-    (new KToggleAction(i18n("Show &Plugin Buttons"), 0, TQT_TQOBJECT(this),
+    (new TDEToggleAction(i18n("Show &Plugin Buttons"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotTogglePluginButtons()), actionCollection(),
                        "show_plugin_buttons"))->setChecked
     (!(mixerOptions & MIXER_OMIT_PLUGINS));
 
-    (new KToggleAction(i18n("Show &Unassigned Faders"), 0, TQT_TQOBJECT(this),
+    (new TDEToggleAction(i18n("Show &Unassigned Faders"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotToggleUnassignedFaders()), actionCollection(),
                        "show_unassigned_faders"))->setChecked
     (mixerOptions & MIXER_SHOW_UNASSIGNED_FADERS);
 
-    KRadioAction *action = 0;
+    TDERadioAction *action = 0;
 
     for (int i = 1; i <= 16; i *= 2) {
         action =
-            new KRadioAction(i18n("1 Input", "%n Inputs", i),
+            new TDERadioAction(i18n("1 Input", "%n Inputs", i),
                              0, TQT_TQOBJECT(this),
                              TQT_SLOT(slotSetInputCountFromAction()), actionCollection(),
                              TQString("inputs_%1").arg(i).ascii());
@@ -190,7 +190,7 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
             action->setChecked(true);
     }
 
-    action = new KRadioAction
+    action = new TDERadioAction
              (i18n("No Submasters"),
               0, TQT_TQOBJECT(this),
               TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
@@ -199,7 +199,7 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
     action->setChecked(true);
 
     for (int i = 2; i <= 8; i *= 2) {
-        action = new KRadioAction
+        action = new TDERadioAction
                  (i18n("1 Submaster", "%n Submasters", i),
                   0, TQT_TQOBJECT(this),
                   TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
@@ -267,7 +267,7 @@ AudioMixerWindow::populate()
     InstrumentList instruments = m_studio->getPresentationInstruments();
     BussList busses = m_studio->getBusses();
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     m_monoPixmap.load(TQString("%1/misc/mono.xpm").arg(pixmapDir));
     m_stereoPixmap.load(TQString("%1/misc/stereo.xpm").arg(pixmapDir));
 
@@ -1584,7 +1584,7 @@ AudioMixerWindow::slotUpdateFaderVisibility()
 {
     bool d = !(m_studio->getMixerDisplayOptions() & MIXER_OMIT_FADERS);
 
-    KToggleAction *action = dynamic_cast<KToggleAction *>
+    TDEToggleAction *action = dynamic_cast<TDEToggleAction *>
                             (actionCollection()->action("show_audio_faders"));
     if (action) {
         action->setChecked(d);
@@ -1616,7 +1616,7 @@ AudioMixerWindow::slotToggleSynthFaders()
 void
 AudioMixerWindow::slotUpdateSynthFaderVisibility()
 {
-    KToggleAction *action = dynamic_cast<KToggleAction *>
+    TDEToggleAction *action = dynamic_cast<TDEToggleAction *>
                             (actionCollection()->action("show_synth_faders"));
     if (!action)
         return ;
@@ -1648,7 +1648,7 @@ AudioMixerWindow::slotToggleSubmasters()
 void
 AudioMixerWindow::slotUpdateSubmasterVisibility()
 {
-    KToggleAction *action = dynamic_cast<KToggleAction *>
+    TDEToggleAction *action = dynamic_cast<TDEToggleAction *>
                             (actionCollection()->action("show_audio_submasters"));
     if (!action)
         return ;
@@ -1678,7 +1678,7 @@ AudioMixerWindow::slotTogglePluginButtons()
 void
 AudioMixerWindow::slotUpdatePluginButtonVisibility()
 {
-    KToggleAction *action = dynamic_cast<KToggleAction *>
+    TDEToggleAction *action = dynamic_cast<TDEToggleAction *>
                             (actionCollection()->action("show_plugin_buttons"));
     if (!action)
         return ;
@@ -1697,7 +1697,7 @@ AudioMixerWindow::slotUpdatePluginButtonVisibility()
 void
 AudioMixerWindow::slotToggleUnassignedFaders()
 {
-    KToggleAction *action = dynamic_cast<KToggleAction *>
+    TDEToggleAction *action = dynamic_cast<TDEToggleAction *>
                             (actionCollection()->action("show_unassigned_faders"));
     if (!action)
         return ;
