@@ -25,9 +25,9 @@
 
 #include "BankEditorDialog.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
@@ -47,15 +47,15 @@
 #include "MidiKeyMapListViewItem.h"
 #include "MidiKeyMappingEditor.h"
 #include "MidiProgramsEditor.h"
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcombobox.h>
 #include <kcommand.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
-#include <klistview.h>
-#include <kmainwindow.h>
-#include <kmessagebox.h>
-#include <kstdaccel.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
+#include <tdelistview.h>
+#include <tdemainwindow.h>
+#include <tdemessagebox.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
 #include <kxmlguiclient.h>
 #include <tqcheckbox.h>
@@ -81,7 +81,7 @@ namespace Rosegarden
 BankEditorDialog::BankEditorDialog(TQWidget *parent,
                                    RosegardenGUIDoc *doc,
                                    DeviceId defaultDevice):
-        KMainWindow(parent, "bankeditordialog"),
+        TDEMainWindow(parent, "bankeditordialog"),
         m_studio(&doc->getStudio()),
         m_doc(doc),
         m_copyBank(Device::NO_DEVICE, -1),
@@ -124,7 +124,7 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
     // Left-side list view
     //
     TQVBox* leftPart = new TQVBox(splitter);
-    m_listView = new KListView(leftPart);
+    m_listView = new TDEListView(leftPart);
     m_listView->addColumn(i18n("MIDI Device"));
     m_listView->addColumn(i18n("Type"));
     m_listView->addColumn(i18n("MSB"));
@@ -303,7 +303,7 @@ BankEditorDialog::~BankEditorDialog()
 void
 BankEditorDialog::setupActions()
 {
-    KAction* close = KStdAction::close (TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()), actionCollection());
+    TDEAction* close = KStdAction::close (TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()), actionCollection());
 
     m_closeButton->setText(close->text());
     connect(m_closeButton, TQT_SIGNAL(clicked()),
@@ -315,15 +315,15 @@ BankEditorDialog::setupActions()
     // some adjustments
 
 
-    new KToolBarPopupAction(i18n("Und&o"),
-                            "undo",
-                            KStdAccel::key(KStdAccel::Undo),
+    new TDEToolBarPopupAction(i18n("Und&o"),
+                            "edit-undo",
+                            TDEStdAccel::key(TDEStdAccel::Undo),
                             actionCollection(),
                             KStdAction::stdName(KStdAction::Undo));
 
-    new KToolBarPopupAction(i18n("Re&do"),
-                            "redo",
-                            KStdAccel::key(KStdAccel::Redo),
+    new TDEToolBarPopupAction(i18n("Re&do"),
+                            "edit-redo",
+                            TDEStdAccel::key(TDEStdAccel::Redo),
                             actionCollection(),
                             KStdAction::stdName(KStdAction::Redo));
 
@@ -1462,7 +1462,7 @@ BankEditorDialog::getCommandHistory()
 void
 BankEditorDialog::slotImport()
 {
-    TQString deviceDir = KGlobal::dirs()->findResource("appdata", "library/");
+    TQString deviceDir = TDEGlobal::dirs()->findResource("appdata", "library/");
     TQDir dir(deviceDir);
     if (!dir.exists()) {
         deviceDir = ":ROSEGARDENDEVICE";
@@ -1706,7 +1706,7 @@ BankEditorDialog::closeEvent(TQCloseEvent *e)
     }
 
     emit closing();
-    KMainWindow::closeEvent(e);
+    TDEMainWindow::closeEvent(e);
 }
 
 }
