@@ -25,11 +25,11 @@
 #ifndef _RG_AUDIOLISTVIEW_H_
 #define _RG_AUDIOLISTVIEW_H_
 
-#include <klistview.h>
+#include <tdelistview.h>
 
 namespace Rosegarden {
         
-class AudioListView : public KListView
+class AudioListView : public TDEListView
 {
 public:
     AudioListView(TQWidget *parent = 0, const char *name = 0);
