@@ -24,13 +24,8 @@
 
 #include <string>
 #include <iostream>
-
-#if (__GNUC__ < 3)
-#include <strstream>
-#define stringstream strstream
-#else
 #include <sstream>
-#endif
+
 
 // A staggeringly simple-minded audit trail implementation.
 
