@@ -27,6 +27,7 @@
 #include <string>
 #include <cstdio>
 #include <algorithm>
+#include <sstream>
 
 #include "Midi.h"
 #include "MidiFile.h"
@@ -46,13 +47,6 @@
 
 //#define MIDI_DEBUG 1
 
-#if (__GNUC__ < 3)
-#include <strstream>
-#define stringstream strstream
-#else
-#include <sstream>
-#endif
-
 #include <kapp.h>
 
 namespace Rosegarden
